# Geneva

`Geneva` is a multimodal feature engineering platform, built on [LanceDB](https://github.com/lancedb/lancedb). This page only hosts the [API docs](/geneva/api) for Geneva; [find the rest of the docs and tutorials here.](https://docs.lancedb.com/geneva)
